SCRIPT_TAGS = {'DFLT': {'name': 'Default'},
 'adlm': {'name': 'Adlam'},
 'aghb': {'name': 'Caucasian Albanian'},
 'ahom': {'name': 'Ahom'},
 'arab': {'name': 'Arabic'},
 'armi': {'name': 'Imperial Aramaic'},
 'armn': {'name': 'Armenian'},
 'avst': {'name': 'Avestan'},
 'bali': {'name': 'Balinese'},
 'bamu': {'name': 'Bamum'},
 'bass': {'name': 'Bassa Vah'},
 'batk': {'name': 'Batak'},
 'beng': {'name': 'Bangla'},
 'bhks': {'name': 'Bhaiksuki'},
 'bng2': {'name': 'Bangla v.2'},
 'bopo': {'name': 'Bopomofo'},
 'brah': {'name': 'Brahmi'},
 'brai': {'name': 'Braille'},
 'bugi': {'name': 'Buginese'},
 'buhd': {'name': 'Buhid'},
 'byzm': {'name': 'Byzantine Music'},
 'cakm': {'name': 'Chakma'},
 'cans': {'name': 'Canadian Syllabics'},
 'cari': {'name': 'Carian'},
 'cham': {'name': 'Cham'},
 'cher': {'name': 'Cherokee'},
 'chrs': {'name': 'Chorasmian'},
 'copt': {'name': 'Coptic'},
 'cpmn': {'name': 'Cypro-Minoan'},
 'cprt': {'name': 'Cypriot Syllabary'},
 'cyrl': {'name': 'Cyrillic'},
 'dev2': {'name': 'Devanagari v.2'},
 'deva': {'name': 'Devanagari'},
 'diak': {'name': 'Dives Akuru'},
 'dogr': {'name': 'Dogra'},
 'dsrt': {'name': 'Deseret'},
 'dupl': {'name': 'Duployan'},
 'egyp': {'name': 'Egyptian Hieroglyphs'},
 'elba': {'name': 'Elbasan'},
 'elym': {'name': 'Elymaic'},
 'ethi': {'name': 'Ethiopic'},
 'gara': {'name': 'Garay'},
 'geor': {'name': 'Georgian'},
 'gjr2': {'name': 'Gujarati v.2'},
 'glag': {'name': 'Glagolitic'},
 'gong': {'name': 'Gunjala Gondi'},
 'gonm': {'name': 'Masaram Gondi'},
 'goth': {'name': 'Gothic'},
 'gran': {'name': 'Grantha'},
 'grek': {'name': 'Greek'},
 'gujr': {'name': 'Gujarati'},
 'gukh': {'name': 'Gurung Khema'},
 'gur2': {'name': 'Gurmukhi v.2'},
 'guru': {'name': 'Gurmukhi'},
 'hang': {'name': 'Hangul'},
 'hani': {'name': 'CJK Ideographic'},
 'hano': {'name': 'Hanunoo'},
 'hatr': {'name': 'Hatran'},
 'hebr': {'name': 'Hebrew'},
 'hluw': {'name': 'Anatolian Hieroglyphs'},
 'hmng': {'name': 'Pahawh Hmong'},
 'hmnp': {'name': 'Nyiakeng Puachue Hmong'},
 'hung': {'name': 'Old Hungarian'},
 'ital': {'name': 'Old Italic'},
 'jamo': {'name': 'Hangul Jamo'},
 'java': {'name': 'Javanese'},
 'kali': {'name': 'Kayah Li'},
 'kana': {'name': 'Katakana'},
 'kawi': {'name': 'Kawi'},
 'khar': {'name': 'Kharosthi'},
 'khmr': {'name': 'Khmer'},
 'khoj': {'name': 'Khojki'},
 'kits': {'name': 'Khitan Small Script'},
 'knd2': {'name': 'Kannada v.2'},
 'knda': {'name': 'Kannada'},
 'krai': {'name': 'Kirat Rai'},
 'kthi': {'name': 'Kaithi'},
 'lana': {'name': 'Tai Tham (Lanna)'},
 'lao ': {'name': 'Lao'},
 'latn': {'name': 'Latin'},
 'lepc': {'name': 'Lepcha'},
 'limb': {'name': 'Limbu'},
 'lina': {'name': 'Linear A'},
 'linb': {'name': 'Linear B'},
 'lisu': {'name': 'Lisu (Fraser)'},
 'lyci': {'name': 'Lycian'},
 'lydi': {'name': 'Lydian'},
 'mahj': {'name': 'Mahajani'},
 'maka': {'name': 'Makasar'},
 'mand': {'name': 'Mandaic, Mandaean'},
 'mani': {'name': 'Manichaean'},
 'marc': {'name': 'Marchen'},
 'math': {'name': 'Mathematical text layout'},
 'medf': {'name': 'Medefaidrin (Oberi Okaime, Oberi Ɔkaimɛ)'},
 'mend': {'name': 'Mende Kikakui'},
 'merc': {'name': 'Meroitic Cursive'},
 'mero': {'name': 'Meroitic Hieroglyphs'},
 'mlm2': {'name': 'Malayalam v.2'},
 'mlym': {'name': 'Malayalam'},
 'modi': {'name': 'Modi'},
 'mong': {'name': 'Mongolian'},
 'mroo': {'name': 'Mro'},
 'mtei': {'name': 'Meitei Mayek (Meithei, Meetei)'},
 'mult': {'name': 'Multani'},
 'musc': {'name': 'Musical Symbols'},
 'mym2': {'name': 'Myanmar v.2'},
 'mymr': {'name': 'Myanmar'},
 'nagm': {'name': 'Nag Mundari'},
 'nand': {'name': 'Nandinagari'},
 'narb': {'name': 'Old North Arabian'},
 'nbat': {'name': 'Nabataean'},
 'newa': {'name': 'Newa'},
 'nko ': {'name': "N'Ko"},
 'nshu': {'name': 'Nüshu'},
 'ogam': {'name': 'Ogham'},
 'olck': {'name': 'Ol Chiki'},
 'onao': {'name': 'Ol Onal'},
 'orkh': {'name': 'Old Turkic, Orkhon Runic'},
 'ory2': {'name': 'Odia v.2'},
 'orya': {'name': 'Odia'},
 'osge': {'name': 'Osage'},
 'osma': {'name': 'Osmanya'},
 'ougr': {'name': 'Old Uyghur'},
 'palm': {'name': 'Palmyrene'},
 'pauc': {'name': 'Pau Cin Hau'},
 'perm': {'name': 'Old Permic'},
 'phag': {'name': 'Phags-pa'},
 'phli': {'name': 'Inscriptional Pahlavi'},
 'phlp': {'name': 'Psalter Pahlavi'},
 'phnx': {'name': 'Phoenician'},
 'plrd': {'name': 'Miao'},
 'prti': {'name': 'Inscriptional Parthian'},
 'rjng': {'name': 'Rejang'},
 'rohg': {'name': 'Hanifi Rohingya'},
 'runr': {'name': 'Runic'},
 'samr': {'name': 'Samaritan'},
 'sarb': {'name': 'Old South Arabian'},
 'saur': {'name': 'Saurashtra'},
 'sgnw': {'name': 'Sign Writing'},
 'shaw': {'name': 'Shavian'},
 'shrd': {'name': 'Sharada'},
 'sidd': {'name': 'Siddham'},
 'sind': {'name': 'Khudawadi'},
 'sinh': {'name': 'Sinhala'},
 'sogd': {'name': 'Sogdian'},
 'sogo': {'name': 'Old Sogdian'},
 'sora': {'name': 'Sora Sompeng'},
 'soyo': {'name': 'Soyombo'},
 'sund': {'name': 'Sundanese'},
 'sunu': {'name': 'Sunuwar'},
 'sylo': {'name': 'Syloti Nagri'},
 'syrc': {'name': 'Syriac'},
 'tagb': {'name': 'Tagbanwa'},
 'takr': {'name': 'Takri'},
 'tale': {'name': 'Tai Le'},
 'talu': {'name': 'New Tai Lue'},
 'taml': {'name': 'Tamil'},
 'tang': {'name': 'Tangut'},
 'tavt': {'name': 'Tai Viet'},
 'tel2': {'name': 'Telugu v.2'},
 'telu': {'name': 'Telugu'},
 'tfng': {'name': 'Tifinagh'},
 'tglg': {'name': 'Tagalog'},
 'thaa': {'name': 'Thaana'},
 'thai': {'name': 'Thai'},
 'tibt': {'name': 'Tibetan'},
 'tirh': {'name': 'Tirhuta'},
 'tml2': {'name': 'Tamil v.2'},
 'tnsa': {'name': 'Tangsa'},
 'todr': {'name': 'Todhri'},
 'toto': {'name': 'Toto'},
 'tutg': {'name': 'Tulu-Tigalari'},
 'ugar': {'name': 'Ugaritic Cuneiform'},
 'vai ': {'name': 'Vai'},
 'vith': {'name': 'Vithkuqi'},
 'wara': {'name': 'Warang Citi'},
 'wcho': {'name': 'Wancho'},
 'xpeo': {'name': 'Old Persian Cuneiform'},
 'xsux': {'name': 'Sumero-Akkadian Cuneiform'},
 'yezi': {'name': 'Yezidi'},
 'yi  ': {'name': 'Yi'},
 'zanb': {'name': 'Zanabazar Square (Zanabazarin Dörböljin Useg, Xewtee '
                  'Dörböljin Bicig, Horizontal Square Script)'}}
